---
last_modified_on: "2020-04-11"
component_title: "Logfmt Parser"
description: "The Vector `logfmt_parser` transform accepts and outputs `log` events allowing you to parse a log field's value in the logfmt format."
event_types: ["log"]
function_category: "parse"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+logfmt_parser%22
sidebar_label: "logfmt_parser|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/logfmt_parser.rs
status: "beta"
title: "Logfmt Parser Transform"
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `logfmt_parser` transform
accepts and outputs [`log`][docs.data-model.log] events allowing you to parse a
log field's value in the [logfmt][urls.logfmt] format.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/logfmt_parser.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "logfmt_parser" # required
  inputs = ["my-source-id"] # required
  drop_field = true # optional, default
  field = "message" # optional, default

  # Types
  types.status = "int" # example
  types.duration = "float" # example
  types.success = "bool" # example
  types.timestamp = "timestamp|%F" # example
  types.timestamp = "timestamp|%a %b %e %T %Y" # example
  types.parent.child = "int" # example
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "logfmt_parser" # required
  inputs = ["my-source-id"] # required
  drop_field = true # optional, default
  field = "message" # optional, default

  # Types
  types.status = "int" # example
  types.duration = "float" # example
  types.success = "bool" # example
  types.timestamp = "timestamp|%F" # example
  types.timestamp = "timestamp|%a %b %e %T %Y" # example
  types.parent.child = "int" # example
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"drop_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### drop_field

If the specified [`field`](#field) should be dropped (removed) after parsing.




</Field>
<Field
  common={true}
  defaultValue={"message"}
  enumValues={null}
  examples={["message","parent.child","array[0]"]}
  groups={[]}
  name={"field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### field

The log field to parse.

 See [Field Notation Syntax](#field-notation-syntax) and [Format Specification](#format-specification) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"types"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### types

Key/value pairs representing mapped log field names and types. This is used to
coerce log fields into their proper types.



<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"bool":"Coerces `\"true\"`/`/\"false\"`, `\"1\"`/`\"0\"`, and `\"t\"`/`\"f\"` values into boolean.","float":"Coerce to a 64 bit float.","int":"Coerce to a 64 bit integer.","string":"Coerce to a string.","timestamp":"Coerces to a Vector timestamp. [`strptime` specificiers][urls.strptime_specifiers] must be used to parse the string."}}
  examples={[{"status":"int"},{"duration":"float"},{"success":"bool"},{"timestamp":"timestamp|%F"},{"timestamp":"timestamp|%a %b %e %T %Y"},{"parent":{"child":"int"}}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"types"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[field-name]`

A definition of log field type conversions. They key is the log field name and
the value is the type. [`strptime` specifiers][urls.strptime_specifiers] are
supported for the `timestamp` type.




</Field>
</Fields>

</Field>
</Fields>

## Examples

<Tabs
  block={true}
  defaultValue="heroku-router-log"
  select={false}
  values={[{"label":"Heroku Router Log","value":"heroku-router-log"},{"label":"Loosely Structured","value":"loosely-structured"}]}>

<TabItem value="heroku-router-log">

Given the following Heroku router log line:

```json title="log event"
{
  "message": "at=info method=GET path=/ host=myapp.herokuapp.com request_id=8601b555-6a83-4c12-8269-97c8e32cdb22 fwd="204.204.204.204" dyno=web.1 connect=1ms service=18ms status=200 bytes=13 tls_version=tls1.1 protocol=http"
}
```

And the following configuration:

```toml title="vector.toml"
[transforms.<transform-id>]
type = "logfmt"
field = "message"
drop_field = true

types.bytes = "int"
types.status = "int"
```

A [`log` event][docs.data-model.log] will be output with the following structure:

```javascript title="log event"
{
  // ... existing fields
  "at": "info",
  "method": "GET",
  "path": "/",
  "host": "myapp.herokuapp.com",
  "request_id": "8601b555-6a83-4c12-8269-97c8e32cdb22",
  "fwd": "204.204.204.204",
  "dyno": "web.1",
  "connect": "1ms",
  "service": "18ms",
  "status": 200,
  "bytes": 13,
  "tls_version": "tls1.1",
  "protocol": "http"
}
```

A couple of things to note:

1. The `bytes` and `status` fields were coerced into `int`s via the [`types`](#types) options.
2. The `message` field was dropped due to setting [`drop_field`](#drop_field) to `true`.

</TabItem>

<TabItem value="loosely-structured">

The `logfmt_parser` will also parse loosely structured key/value pairs. For
example, given the following `log` event:

```json title="log event"
{
  "message": "info | Sent 200 in 54.2ms duration=54.2ms status=200"
}
```

And the following configuration:

```toml title="vector.toml"
[transforms.<transform-id>]
type = "logfmt"
field = "message"
drop_field = false # keep the field since it contains other data

types.status = "int"
```

A [`log` event][docs.data-model.log] will be output with the following structure:

```javascript title="log event"
{
  // ... existing fields
  "message": "info | Sent 200 in 54.2ms duration=54.2ms status=200",
  "duration": "54.2ms",
  "status": 200
}
```

A couple of things to note:

1. The `status` field was coerced into an `int` via the [`types`](#types) option.
2. The `message` field was _kept_ due to setting [`drop_field`](#drop_field) to `false`.

</TabItem>
</Tabs>

## How It Works

### Complex Processing

If you encounter limitations with the `logfmt_parser`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Field Notation Syntax

The [`field`](#field) options
support [Vector's field notation syntax][docs.reference.field-path-notation],
enabling access to root-level, nested, and array field values. For example:

```toml title="vector.toml"
[transforms.my_logfmt_parser_transform_id]
  # ...
  field = "message"
  field = "parent.child"
  field = "array[0]"
  # ...
```

You can learn more about Vector's field notation in the
[field notation reference][docs.reference.field-path-notation].

### Format Specification

[Logfmt][urls.logfmt] is, unfortunately, a very loosely defined format. There
is no official specification for the format and Vector makes a best effort to
parse key/value pairs delimited with a `=`. It works by splitting the [`field`](#field)'s
value on non-quoted white-space and then splitting each token by a non-quoted
`=` character. This makes the parsing process somewhat flexible in that the
string does not need to be strictly formatted.

For example, the following log line:

```js title="log event"
{
  "message": "Hello world duration=2s user-agent=\"Firefox/47.3 Mozilla/5.0\""
}
```

Will be successfully parsed into:

```js title="log event"
{
  "message": "Hello world duration=2s user-agent=\"Firefox/47.3 Mozilla/5.0\"",
  "duration": "2s",
  "user-agent": "Firefox/47.3 Mozilla/5.0"
}
```

### Key/Value Parsing

This transform can be used for key/value parsing. [Logfmt][urls.logfmt] refers
to a _loosely_ defined spec that parses a key/value pair delimited by a `=`
character. This section, and it's keywords, is primarily added to assist users
in finding this transform for these terms.

### Quoting Values

Values can be quoted to capture spaces, and quotes can be escaped with `\`.
For example

```text
key1="value with spaces" key2="value with spaces and \""
```

Would result in the following `log` event:

```json title="log event"
{
  "key1": "value with spaces",
  "key2": "value with spaces and \""
}
```

### Value Coercion

Values can be coerced upon extraction via the [`types.*`](#types) options. This functions
exactly like the [`coercer` transform][docs.transforms.coercer] except that its
coupled within this transform for convenience.

#### Timestamps

You can coerce values into timestamps via the `timestamp` type:

```toml title="vector.toml"
# ...
types.first_timestamp = "timestamp" # best effort parsing
types.second_timestamp = "timestamp|%Y-%m-%dT%H:%M:%S%z" # ISO8601
# ...
```

As noted above, if you do not specify a specific `strftime` format, Vector
will make a best effort attempt to parse the timestamp against the following
common formats:

| Format               | Description                                  |
|:---------------------|:---------------------------------------------|
| **Without Timezone** |                                              |
| `%F %T`              | YYYY-MM-DD HH:MM:SS                          |
| `%v %T`              | DD-Mmm-YYYY HH:MM:SS                         |
| `FT%T`               | ISO 8601 / RFC 3339 without TZ               |
| `m/%d/%Y:%T`         | US common date format                        |
| `a, %d %b %Y %T`     | RFC 822/2822 without TZ                      |
| `a %d %b %T %Y`      | `date` command output without TZ             |
| `A %d %B %T %Y`      | `date` command output without TZ, long names |
| `a %b %e %T %Y`      | ctime format                                 |
| **With Timezone**    |                                              |
| `%+`                 | ISO 8601 / RFC 3339                          |
| `%a %d %b %T %Z %Y`  | `date` command output                        |
| `%a %d %b %T %z %Y`  | `date` command output, numeric TZ            |
| `%a %d %b %T %#z %Y` | `date` command output, numeric TZ            |
| **UTC Formats**      |                                              |
| `%s`                 | UNIX timestamp                               |
| `%FT%TZ`             | ISO 8601 / RFC 3339 UTC                      |


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.reference.field-path-notation]: /docs/reference/field-path-notation/
[docs.transforms.coercer]: /docs/reference/transforms/coercer/
[urls.logfmt]: https://brandur.org/logfmt
[urls.strptime_specifiers]: https://docs.rs/chrono/0.4.11/chrono/format/strftime/index.html#specifiers
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
